Learn R Programming

areal (version 0.1.8)

ar_stl_asthma: Asthma in St. Louis by Census Tract, 2017

Description

A simple features data set containing the geometry and asthma estimates from the Centers for Disease Control for St. Louis.

Usage

data(ar_stl_asthma)

Arguments

Format

A data frame with 106 rows and 24 variables:

GEOID

full GEOID string

STATEFP

state FIPS code

COUNTYFP

county FIPS code

TRACTCE

tract FIPS code

NAMELSAD

tract name

ALAND

area of tract land, square meters

AWATER

area of tract water, square meters

ASTHMA

percent of residents with current asthma diagnosis, estimated

geometry

simple features geometry

Examples

Run this code
# NOT RUN {
str(ar_stl_asthma)
head(ar_stl_asthma)
summary(ar_stl_asthma$ASTHMA)

# }

Run the code above in your browser using DataLab